@@ -39,7 +39,7 @@ from clam.common.util import RequestWithMethod
 
 #clam.common.formats is deliberately imported _at the end_ 
 
-VERSION = '0.8.2'
+VERSION = '0.9.0'
 
 class FormatError(Exception):
      """This Exception is raised when the CLAM response is not in the valid CLAM XML format"""
@@ -396,8 +396,9 @@ class CLAMData(object):
         if root.tag != 'clam':
             raise FormatError()
             
-        if root.attrib['version'][0:3] != VERSION[0:3]:
-            raise Exception("Version mismatch, CLAM Data API has version " + VERSION + ", but response expects " + root.attrib['version'])                    
+        #if root.attrib['version'][0:3] != VERSION[0:3]:
+        #    raise Exception("Version mismatch, CLAM Data API has version " + VERSION + ", but response expects " + root.attrib['version'])
+                                
         self.system_id = root.attrib['id']
         self.system_name = root.attrib['name']        
         if 'project' in root.attrib:
@@ -1160,6 +1161,10 @@ class InputTemplate(object):
             xml +=" unique=\"yes\""
         else:
             xml +=" unique=\"no\""
+        if self.acceptarchive:
+            xml +=" acceptarchive=\"yes\""
+        else:
+            xml +=" acceptarchive=\"no\""            
         xml += ">\n"
         for parameter in self.parameters:
             xml += parameter.xml(indent+"\t") + "\n"
@@ -1192,6 +1197,11 @@ class InputTemplate(object):
                 kwargs['unique'] = True
             else:
                 kwargs['unique'] = False
+        if 'acceptarchive' in node.attrib:
+            if node.attrib['acceptarchive'].lower() == 'yes' or node.attrib['acceptarchive'].lower() == 'true' or node.attrib['acceptarchive'].lower() == '1':
+                kwargs['acceptarchive'] = True
+            else:
+                kwargs['acceptarchive'] = False
             
         #find formatclass
         if format in vars(clam.common.formats):
@@ -1223,6 +1233,8 @@ class InputTemplate(object):
             d['filename'] = self.filename
         if self.extension:
             d['extension'] = self.extension
+        if self.acceptarchive:
+            d['acceptarchive'] = self.acceptarchive
         #d['parameters'] = {}
 
         #The actual parameters are included as XML, and transformed by clam.js using XSLT (parameter.xsl) to generate the forms
