@@ -74,7 +74,10 @@ class SimpleTableViewer(AbstractViewer):
         super(SimpleTableViewer,self).__init__(**kwargs)   
                 
     def read(self, file):
-        file = csv.reader(open(file,'r'), delimiter=self.delimiter, quotechar=self.quotechar)        
+        if self.quotechar:
+            file = csv.reader(file, delimiter=self.delimiter, quotechar=self.quotechar)
+        else:        
+            file = csv.reader(file, delimiter=self.delimiter)
         for line in file:
             yield line
     
@@ -113,7 +116,15 @@ class XSLTViewer(AbstractViewer):
         transform = etree.XSLT(xslt_doc)
 
         #f = file.open()
-        xml_doc = etree.parse(StringIO("".join(file.readlines()).encode('utf-8')))
+        lines = file.readlines()
+        if lines:
+            if isinstance(lines[0], unicode):
+                xml_doc = etree.parse(StringIO("".join( ( x.encode('utf-8') for x in lines) ) ))
+            else:        
+                xml_doc = etree.parse(StringIO("".join(lines) ))
+        else:
+            return "(no data)" 
+        
         return str(transform(xml_doc))
 
 class FoLiAViewer(AbstractViewer):
@@ -126,6 +137,7 @@ class FoLiAViewer(AbstractViewer):
         transform = etree.XSLT(xslt_doc)
 
         #f = file.open()
+        
         xml_doc = etree.parse(StringIO("".join(file.readlines()).encode('utf-8')))
         return str(transform(xml_doc))
 
